==> jasperreports-javaflow-6.20.5-sources.jar: net/sf/jasperreports/export/SimplePptxReportConfiguration.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2023 Cloud Software Group, Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.export;


/**
 * @author Sanda Zaharia (shertage@users.sourceforge.net)
 */
public class SimplePptxReportConfiguration extends SimpleReportExportConfiguration implements PptxReportConfiguration
{
	private Boolean isIgnoreHyperlink;
	private String hideSlideMasterPages;

	
	/**
	 * 
	 */
	public SimplePptxReportConfiguration()
	{
	}
	
	@Override
	public Boolean isIgnoreHyperlink()
	{
		return isIgnoreHyperlink;
	}
	
	/**
	 * 
	 */
	public void setIgnoreHyperlink(Boolean isIgnoreHyperlink)
	{
		this.isIgnoreHyperlink = isIgnoreHyperlink;
	}
	
	@Override
	public String getHideSlideMasterPages()
	{
		return hideSlideMasterPages;
	}
	
	/**
	 * 
	 */
	public void setHideSlideMasterPages(String hideSlideMasterPages)
	{
		this.hideSlideMasterPages = hideSlideMasterPages;
	}
}

==> jasperreports-javaflow-6.21.2-sources.jar: net/sf/jasperreports/export/SimplePptxReportConfiguration.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2023 Cloud Software Group, Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.export;


/**
 * @author Sanda Zaharia (shertage@users.sourceforge.net)
 */
public class SimplePptxReportConfiguration extends SimpleReportExportConfiguration implements PptxReportConfiguration
{
	private Boolean isIgnoreHyperlink;
	private String hideSlideMasterPages;
	private Boolean isFrameAsTable;

	
	/**
	 * 
	 */
	public SimplePptxReportConfiguration()
	{
	}
	
	@Override
	public Boolean isIgnoreHyperlink()
	{
		return isIgnoreHyperlink;
	}
	
	/**
	 * 
	 */
	public void setIgnoreHyperlink(Boolean isIgnoreHyperlink)
	{
		this.isIgnoreHyperlink = isIgnoreHyperlink;
	}
	
	@Override
	public String getHideSlideMasterPages()
	{
		return hideSlideMasterPages;
	}
	
	/**
	 * 
	 */
	public void setHideSlideMasterPages(String hideSlideMasterPages)
	{
		this.hideSlideMasterPages = hideSlideMasterPages;
	}
	
	@Override
	public Boolean isFrameAsTable()
	{
		return isFrameAsTable;
	}
	
	/**
	 * 
	 */
	public void setFrameAsTable(Boolean isFrameAsTable)
	{
		this.isFrameAsTable = isFrameAsTable;
	}
}
